use strict;

my $rss = 0;
my $atom = 0;
my $date;

while (<STDIN>)
{
  chop;
  if (/\d\d\d\d-\d\d-\d\d/) { $date = $_; }
  elsif (/(\d+) rss/) { $rss = $1; }
  elsif (/(\d+) atom/) { $atom = $1; }
}

print "$date\t$rss\t$atom\n";

